summary refs log tree commit diff
path: root/synapse/handlers
diff options
context:
space:
mode:
Diffstat (limited to 'synapse/handlers')
-rw-r--r--synapse/handlers/message.py8
1 files changed, 6 insertions, 2 deletions
diff --git a/synapse/handlers/message.py b/synapse/handlers/message.py
index 8de4b8e816..41a35ce510 100644
--- a/synapse/handlers/message.py
+++ b/synapse/handlers/message.py
@@ -693,9 +693,13 @@ class EventCreationHandler:
         if require_consent and not is_exempt:
             await self.assert_accepted_privacy_policy(requester)
 
         # Save the the device ID and the transaction ID in the event internal metadata.
         # This is useful to determine if we should echo the transaction_id in events.
         # See `synapse.events.utils.EventClientSerializer.serialize_event`
+        if requester.access_token_id is not None:
+            builder.internal_metadata.token_id = requester.access_token_id
+
         if requester.device_id is not None:
             builder.internal_metadata.device_id = requester.device_id
@@ -693,9 +693,13 @@ class EventCreationHandler:
             await self.assert_accepted_privacy_policy(requester)
 
-        # Save the the device ID and the transaction ID in the event internal metadata.
-        # This is useful to determine if we should echo the transaction_id in events.
+        # Save the access token ID, the device ID and the transaction ID in the event
+        # internal metadata. This is useful to determine if we should echo the
+        # transaction_id in events.
         # See `synapse.events.utils.EventClientSerializer.serialize_event`